/*
 * This file is part of Jstacs.
 *
 * Jstacs is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Jstacs is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Jstacs. If not, see <http://www.gnu.org/licenses/>.
 * 
 * For more information on Jstacs, visit http://www.jstacs.de
 */

package de.jstacs.results;

import java.awt.image.BufferedImage;

import de.jstacs.DataType;
import de.jstacs.NonParsableException;

/**
 * A class for results that are images of the PNG format. The images themselves
 * cannot be stored to an XML representation and thus only the description
 * (name, etc.) is stored.
 * 
 * @author Jan Grau
 */
public class ImageResult extends Result {

	/**
	 * The image as {@link BufferedImage}
	 */
	private BufferedImage image;

	/**
	 * Constructs a new {@link ImageResult} from a {@link BufferedImage}.
	 * 
	 * @param name
	 *            the name of the image
	 * @param comment
	 *            a comment on the image
	 * @param image
	 *            the image itself
	 */
	public ImageResult(String name, String comment, BufferedImage image) {
		super(name, comment, DataType.PNG);
		this.image = image;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see de.jstacs.results.Result#getResult()
	 */
	@Override
	public BufferedImage getResult() {
		return image;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see de.jstacs.Storable#toXML()
	 */
	public StringBuffer toXML() {
		try {
			CategoricalResult res = new CategoricalResult(DataType.STRING,
					name, comment,
					"An image cannot be saved to an XML representation.");
			return res.toXML();
		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see de.jstacs.results.Result#fromXML(java.lang.StringBuffer)
	 */
	@Override
	protected void fromXML(StringBuffer representation)
			throws NonParsableException {
		CategoricalResult res = new CategoricalResult(representation);
		this.name = res.name;
		this.comment = res.comment + " (" + res.getResult().toString() + ")";
		this.datatype = DataType.PNG;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return name + ": [image]";
	}
}
